==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/CreateEventToClassSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToClass;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToClassSet;
import io.ciera.tool.sql.ooaofooa.event.CreateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateSMEventStatementSetImpl;

import java.util.Arrays;
import java.util.List;


public class CreateEventToClassSetImpl extends InstanceSet<CreateEventToClassSet,CreateEventToClass> implements CreateEventToClassSet {

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( CreateEventToClass createeventtoclass : this ) createeventtoclass.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public CreateSMEventStatementSet R704_is_a_CreateSMEventStatement() throws XtumlException {
        CreateSMEventStatementSet createsmeventstatementset = new CreateSMEventStatementSetImpl();
        for ( CreateEventToClass createeventtoclass : this ) createsmeventstatementset.add( createeventtoclass.R704_is_a_CreateSMEventStatement() );
        return createsmeventstatementset;
    }


    @Override
    public CreateEventToClass nullElement() {
        return CreateEventToClassImpl.EMPTY_CREATEEVENTTOCLASS;
    }

    @Override
    public CreateEventToClassSet emptySet() {
      return new CreateEventToClassSetImpl();
    }

    @Override
    public CreateEventToClassSet value() {
        return this;
    }

    @Override
    public List<CreateEventToClass> elements() {
        return Arrays.asList(toArray(new CreateEventToClass[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/CreateEventToClassSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToClass;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToClassSet;
import io.ciera.tool.sql.ooaofooa.event.CreateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateSMEventStatementSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class CreateEventToClassSetImpl extends InstanceSet<CreateEventToClassSet,CreateEventToClass> implements CreateEventToClassSet {

    public CreateEventToClassSetImpl() {
    }

    public CreateEventToClassSetImpl(Comparator<? super CreateEventToClass> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( CreateEventToClass createeventtoclass : this ) createeventtoclass.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public CreateSMEventStatementSet R704_is_a_CreateSMEventStatement() throws XtumlException {
        CreateSMEventStatementSet createsmeventstatementset = new CreateSMEventStatementSetImpl();
        for ( CreateEventToClass createeventtoclass : this ) createsmeventstatementset.add( createeventtoclass.R704_is_a_CreateSMEventStatement() );
        return createsmeventstatementset;
    }


    @Override
    public CreateEventToClass nullElement() {
        return CreateEventToClassImpl.EMPTY_CREATEEVENTTOCLASS;
    }

    @Override
    public CreateEventToClassSet emptySet() {
      return new CreateEventToClassSetImpl();
    }

    @Override
    public CreateEventToClassSet emptySet(Comparator<? super CreateEventToClass> comp) {
      return new CreateEventToClassSetImpl(comp);
    }

    @Override
    public CreateEventToClassSet value() {
        return this;
    }

    @Override
    public List<CreateEventToClass> elements() {
        return Arrays.asList(toArray(new CreateEventToClass[0]));
    }

}
